lpschedule-generator
====================

Python package that enables the FSF_ to write the LibrePlanet_
schedule in Markdown_.

See "Installation_" to get started.

.. _Installation: https://ricketyspace.net/lpschedule-generator/install
.. _FSF: https://fsf.org
.. _LibrePlanet: https://libreplanet.org/conference
.. _Markdown: https://daringfireball.net/projects/markdown
